;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "igist" "20251023.848"
  "List, create, update and delete GitHub gists."
  '((emacs     "29.1")
    (ghub      "4.2.2")
    (transient "0.8.5"))
  :url "https://github.com/KarimAziev/igist"
  :commit "badbc1302e6f83cfebd304c6332b321ca3313f21"
  :revdesc "badbc1302e6f"
  :keywords '("tools")
  :authors '(("Karim Aziiev" . "karim.aziiev@gmail.com"))
  :maintainers '(("Karim Aziiev" . "karim.aziiev@gmail.com")))
